@@ -1,7 +1,7 @@
 package Bencher::Scenario::RegexpCommonVsRegexpPattern::Startup;
 
-our $DATE = '2016-09-14'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2017-01-25'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -39,7 +39,7 @@ Bencher::Scenario::RegexpCommonVsRegexpPattern::Startup - Benchmark module start
 
 =head1 VERSION
 
-This document describes version 0.002 of Bencher::Scenario::RegexpCommonVsRegexpPattern::Startup (from Perl distribution Bencher-Scenarios-RegexpCommonVsRegexpPattern), released on 2016-09-14.
+This document describes version 0.003 of Bencher::Scenario::RegexpCommonVsRegexpPattern::Startup (from Perl distribution Bencher-Scenarios-RegexpCommonVsRegexpPattern), released on 2017-01-25.
 
 =head1 SYNOPSIS
 
@@ -49,13 +49,19 @@ To run benchmark with default option:
 
 For more options (dump scenario, list/include/exclude/add participants, list/include/exclude/add datasets, etc), see L<bencher> or run C<bencher --help>.
 
+=head1 DESCRIPTION
+
+Loading L<Regexp::Common> with C<no_defaults> (i.e. C<use Regexp::Common
+'no_defaults>) actually incurs only a little overhead, compared to just C<use
+Regexp::Common>.
+
 =head1 BENCHMARKED MODULES
 
 Version numbers shown below are the versions used when running the sample benchmark.
 
 L<Regexp::Common> 2016060801
 
-L<Regexp::Pattern> 0.1.2
+L<Regexp::Pattern> 0.1.4
 
 =head1 BENCHMARK PARTICIPANTS
 
@@ -81,7 +87,7 @@ L<Regexp::Pattern> 0.1.2
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.24.0 >>, CPU: I<< Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
+Run on: perl: I<< v5.24.0 >>, CPU: I<< Intel(R) Core(TM) M-5Y71 CPU @ 1.20GHz (2 cores) >>, OS: I<< GNU/Linux LinuxMint version 17.3 >>, OS kernel: I<< Linux version 3.19.0-32-generic >>.
 
 Benchmark with default options (C<< bencher -m RegexpCommonVsRegexpPattern::Startup >>):
 
@@ -89,17 +95,14 @@ Benchmark with default options (C<< bencher -m RegexpCommonVsRegexpPattern::Star
  +---------------+-----------+-----------+------------+-----------+---------+
  | participant   | rate (/s) | time (ms) | vs_slowest |  errors   | samples |
  +---------------+-----------+-----------+------------+-----------+---------+
- | RC_defaults   |        11 |      88   |          1 |   0.00079 |      20 |
- | RC_nodefaults |       120 |       8.6 |         10 | 4.6e-05   |      21 |
- | RP            |       210 |       4.7 |         19 | 1.8e-05   |      21 |
- | baseline      |       300 |       4   |         20 | 4.3e-05   |      21 |
+ | RC_defaults   |        12 |      81   |        1   |   0.00013 |      21 |
+ | RC_nodefaults |       110 |       9.5 |        8.5 | 2.7e-05   |      20 |
+ | RP            |       160 |       6.2 |       13   | 2.1e-05   |      20 |
+ | baseline      |       220 |       4.5 |       18   |   1e-05   |      20 |
  +---------------+-----------+-----------+------------+-----------+---------+
 
-=head1 DESCRIPTION
 
-Loading L<Regexp::Common> with C<no_defaults> (i.e. C<use Regexp::Common
-'no_defaults>) actually incurs only a little overhead, compared to just C<use
-Regexp::Common>.
+To display as an interactive HTML table on a browser, you can add option C<--format html+datatables>.
 
 =head1 HOMEPAGE
 
@@ -123,7 +126,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
